pub struct SharedPolicy { /* private fields */ }Expand description
Shared policy wrapper that allows the collection thread to read the policy while the main thread updates weights.
Implementations
pub fn new(policy: CandleActorCritic) -> Self
Sourcepub fn clone_ref(&self) -> Arc<RwLock<CandleActorCritic>>
pub fn clone_ref(&self) -> Arc<RwLock<CandleActorCritic>>
Get a clone of the Arc for the collection thread.